# Changelog

## 0.7.0 (2025-07-06)

Full Changelog: [v0.6.0...v0.7.0](https://github.com/quarklabsai/quarkupy/compare/v0.6.0...v0.7.0)

### Features

* **api:** api update ([34f0acc](https://github.com/quarklabsai/quarkupy/commit/34f0acc2ce93426c794e80511b18ca66d236e3dd))

## 0.6.0 (2025-07-05)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/quarklabsai/quarkupy/compare/v0.5.0...v0.6.0)

### Features

* **api:** api update ([ddc7071](https://github.com/quarklabsai/quarkupy/commit/ddc7071586f34ff438b238811958606a48fcf2a3))
* **api:** manual updates ([68a0c27](https://github.com/quarklabsai/quarkupy/commit/68a0c273ffbe623b312d6501603eb4094a7b0223))

## 0.5.0 (2025-07-03)

Full Changelog: [v0.4.0...v0.5.0](https://github.com/quarklabsai/quarkupy/compare/v0.4.0...v0.5.0)

### Features

* **api:** api update ([4a46252](https://github.com/quarklabsai/quarkupy/commit/4a4625295183ec191ee6c812aef518a3e629f658))
* **api:** api update ([18a7b78](https://github.com/quarklabsai/quarkupy/commit/18a7b78df099a71b3b724a253a51d8d880f8a201))
* **api:** api update ([4e6f1bb](https://github.com/quarklabsai/quarkupy/commit/4e6f1bb88fecc27e49ef876333d4c25661cd7e95))
* **api:** api update ([4cf4a7c](https://github.com/quarklabsai/quarkupy/commit/4cf4a7c7344e017086ccd8ef3d6f0eb8c946eca0))
* **api:** api update ([3b38924](https://github.com/quarklabsai/quarkupy/commit/3b389247a7f06a2755ce0552b4326a606bbbef72))
* **api:** api update ([65aeb10](https://github.com/quarklabsai/quarkupy/commit/65aeb10ab7fb463f83587f612b498fed11d81825))
* **api:** manual updates ([fcf62a1](https://github.com/quarklabsai/quarkupy/commit/fcf62a15c59f6ac3bdca031d8057f0803f3e6004))
* **api:** manual updates ([3ca585d](https://github.com/quarklabsai/quarkupy/commit/3ca585d7a0c447f4e3ef9c0a80ad2ac153f18688))
* **api:** manual updates ([d7353af](https://github.com/quarklabsai/quarkupy/commit/d7353af1348f1a29c37951f5383b28f8c8fbbe99))
* **api:** manual updates ([a30285b](https://github.com/quarklabsai/quarkupy/commit/a30285b216b49f045a7a6b7155055c3d596dca3a))
* **api:** manual updates ([cebf187](https://github.com/quarklabsai/quarkupy/commit/cebf1871a5d558c402a82a53a5f191d64cca26be))
* **api:** manual updates ([1ff9e9b](https://github.com/quarklabsai/quarkupy/commit/1ff9e9b9fdaa0851439208a2cf9942dae24902cf))
* **api:** manual updates ([b454144](https://github.com/quarklabsai/quarkupy/commit/b4541448ad075850f3a611473a3b92946178208e))
* **api:** manual updates ([4c40293](https://github.com/quarklabsai/quarkupy/commit/4c402933357a18564fe1a28bf8b2ebb855491ee6))
* **api:** manual updates ([0572947](https://github.com/quarklabsai/quarkupy/commit/0572947e2df7933814d7d57ab4a28243c7e7d9f2))
* **api:** manual updates ([e7cf93f](https://github.com/quarklabsai/quarkupy/commit/e7cf93f15a9eb037688ff46e20e706bfd0d7facc))
* **api:** manual updates ([d8f2caf](https://github.com/quarklabsai/quarkupy/commit/d8f2caf0e7f50049c8c4243fbffe5561ebc196ab))
* **api:** update via SDK Studio ([912d144](https://github.com/quarklabsai/quarkupy/commit/912d144d2eb4d3fdf03d3173acde3f7ab6714753))
* **api:** update via SDK Studio ([903b816](https://github.com/quarklabsai/quarkupy/commit/903b8160e4bababaf81a39c79c10b39e6b1cd260))
* **api:** update via SDK Studio ([acbb858](https://github.com/quarklabsai/quarkupy/commit/acbb858b104993cbb388b3cabcb8de0131b3bd95))
* **api:** update via SDK Studio ([c91f274](https://github.com/quarklabsai/quarkupy/commit/c91f2746576e4d60e14923631bfde39f372f8c56))
* **api:** update via SDK Studio ([80e74f9](https://github.com/quarklabsai/quarkupy/commit/80e74f9daccc7b4befefd7bf61ba853cb2083313))
* **api:** update via SDK Studio ([c9c87e0](https://github.com/quarklabsai/quarkupy/commit/c9c87e0542f6dae7e089fb2cb6d618dc2a3f38a0))
* **api:** update via SDK Studio ([358d5ef](https://github.com/quarklabsai/quarkupy/commit/358d5ef9674df1d17585ce66364e18b7561e7786))
* **api:** update via SDK Studio ([6f03f44](https://github.com/quarklabsai/quarkupy/commit/6f03f44bd16c50e2c0fb2088acae04223f8a4ae0))
* **api:** update via SDK Studio ([38179db](https://github.com/quarklabsai/quarkupy/commit/38179db096ad24d8ae2e321dc202d3870b6736df))
* **api:** update via SDK Studio ([b676a9f](https://github.com/quarklabsai/quarkupy/commit/b676a9fb4eb5f38ee6a9a65f6f3b442f9d83bddc))
* **api:** update via SDK Studio ([e265611](https://github.com/quarklabsai/quarkupy/commit/e265611a9062a340533cfef1f1c26940b22c7731))
* **api:** update via SDK Studio ([f537948](https://github.com/quarklabsai/quarkupy/commit/f53794812dee9fe02b59f63cb6b998b7806264c4))
* **api:** update via SDK Studio ([1d53583](https://github.com/quarklabsai/quarkupy/commit/1d53583d718cf706528af2ce696dc9946185a911))
* **api:** update via SDK Studio ([d721d48](https://github.com/quarklabsai/quarkupy/commit/d721d484324611932ff43c6028d4a1702382bd7a))
* **api:** update via SDK Studio ([a560faf](https://github.com/quarklabsai/quarkupy/commit/a560fafe705bfae919f759df6e08efc1b792fb2b))
* **api:** update via SDK Studio ([a679452](https://github.com/quarklabsai/quarkupy/commit/a679452b0cd3ce615b83118353e2b527609afabf))
* **api:** update via SDK Studio ([810ca9c](https://github.com/quarklabsai/quarkupy/commit/810ca9c0cc1b49aecae30f006549f85078415758))
* **api:** update via SDK Studio ([3a26651](https://github.com/quarklabsai/quarkupy/commit/3a26651d3d5cd3aa61570347b08440ddb905bc2b))
* **api:** update via SDK Studio ([39c6187](https://github.com/quarklabsai/quarkupy/commit/39c6187398ee2737ae29e532585c704ea35ce3f3))
* **api:** update via SDK Studio ([79335b1](https://github.com/quarklabsai/quarkupy/commit/79335b1cce9440fc6bc347b512311fa208970d47))
* **api:** update via SDK Studio ([76c3baf](https://github.com/quarklabsai/quarkupy/commit/76c3baf3578741eceac1747b6998c7ed4201b502))
* **api:** update via SDK Studio ([e673847](https://github.com/quarklabsai/quarkupy/commit/e673847f2d9e49ccf8d9b56dc96cb1acd0806550))
* **api:** update via SDK Studio ([aad1e18](https://github.com/quarklabsai/quarkupy/commit/aad1e18f69d93775d00b2e06ff0728b1865d3bec))
* **api:** update via SDK Studio ([7621aef](https://github.com/quarklabsai/quarkupy/commit/7621aefae5292237cd011982846f0aba777604cf))
* **api:** update via SDK Studio ([3a4b01f](https://github.com/quarklabsai/quarkupy/commit/3a4b01f1fe2d6ffee011154eff8d422d0c1515c8))
* **api:** update via SDK Studio ([7acd65d](https://github.com/quarklabsai/quarkupy/commit/7acd65dcafb9250f7fe7b1c1cac276cde7d52ead))
* **api:** update via SDK Studio ([fd901e8](https://github.com/quarklabsai/quarkupy/commit/fd901e86b4b6db1b144874659eae1dc685c05883))
* **api:** update via SDK Studio ([9f6e3f1](https://github.com/quarklabsai/quarkupy/commit/9f6e3f18e63f5ad3647d224c94f34126658715bc))
* **api:** update via SDK Studio ([f3ae15e](https://github.com/quarklabsai/quarkupy/commit/f3ae15eaf00460af0d2e1ddaef4f2bb2eb033796))
* **api:** update via SDK Studio ([f501d36](https://github.com/quarklabsai/quarkupy/commit/f501d3699c58c922b4ff98c12d10acb21ba9f252))
* **api:** update via SDK Studio ([3b231cb](https://github.com/quarklabsai/quarkupy/commit/3b231cbca70dcec2f6c2ba2e403007f25692cb12))
* **api:** update via SDK Studio ([5ca50d3](https://github.com/quarklabsai/quarkupy/commit/5ca50d3a9fa03ca27d917edae215af631082d6ec))
* **api:** update via SDK Studio ([8cb2c16](https://github.com/quarklabsai/quarkupy/commit/8cb2c167245d302e31db694121dbb877b59d26ab))
* **api:** update via SDK Studio ([57af12e](https://github.com/quarklabsai/quarkupy/commit/57af12e5c162607b2aa15c143a766714dc187328))
* **api:** update via SDK Studio ([d529592](https://github.com/quarklabsai/quarkupy/commit/d5295926809aff8159cc6478b1c358daaf11be91))
* **api:** update via SDK Studio ([49f0a79](https://github.com/quarklabsai/quarkupy/commit/49f0a79a0cd1b5082c8c32d4407ae86e37445730))
* **api:** update via SDK Studio ([f01de4a](https://github.com/quarklabsai/quarkupy/commit/f01de4ad9488325d6c722c19e42fe17238faa9ab))
* **api:** update via SDK Studio ([4626c10](https://github.com/quarklabsai/quarkupy/commit/4626c108de77e3aa80d2023c7bc901271a06ad22))
* **client:** add follow_redirects request option ([71b858c](https://github.com/quarklabsai/quarkupy/commit/71b858c1b02a223e69959a469d823fa310583653))
* **client:** add follow_redirects request option ([1a739c4](https://github.com/quarklabsai/quarkupy/commit/1a739c45df84b33af102669d2cff91528828f7d3))
* **client:** add support for aiohttp ([d6a3717](https://github.com/quarklabsai/quarkupy/commit/d6a37178c22f84c44c3140872ce68ec1155d2105))
* **client:** add support for aiohttp ([043e887](https://github.com/quarklabsai/quarkupy/commit/043e887eb2ecf7e1db9349d16f5ccd636a06c312))


### Bug Fixes

* **ci:** correct conditional ([c800acf](https://github.com/quarklabsai/quarkupy/commit/c800acf52213d93f6b0ccb4ec7465dd9f2eb47ea))
* **ci:** release-doctor — report correct token name ([a97a2b2](https://github.com/quarklabsai/quarkupy/commit/a97a2b2b8a802f65fb46cb14b2a4975644e7e3ff))
* **client:** correctly parse binary response | stream ([285883d](https://github.com/quarklabsai/quarkupy/commit/285883ddf47441d06667083d3ec8a3da571c21d2))
* **client:** correctly parse binary response | stream ([e0df280](https://github.com/quarklabsai/quarkupy/commit/e0df2802cbab68b948e989bc3e00abf4b2ec2bca))
* **docs/api:** remove references to nonexistent types ([52601ec](https://github.com/quarklabsai/quarkupy/commit/52601ec2704a3f0794ae3db45a4f56898a929ce4))
* **docs/api:** remove references to nonexistent types ([caa3528](https://github.com/quarklabsai/quarkupy/commit/caa352854e7a0ae177603b23847d2e120676a3b5))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([db499ff](https://github.com/quarklabsai/quarkupy/commit/db499ff1d0e8011219d2f14642e3ee4fb799340c))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([7497832](https://github.com/quarklabsai/quarkupy/commit/74978322373d54be27322d54a057986b091693c6))


### Chores

* **ci:** change upload type ([e539e42](https://github.com/quarklabsai/quarkupy/commit/e539e423c65f9b4e422687996d8fea6a07706ca0))
* **ci:** enable for pull requests ([3a27142](https://github.com/quarklabsai/quarkupy/commit/3a271423b8682268be4816ed37b956469e228532))
* **ci:** enable for pull requests ([ef63563](https://github.com/quarklabsai/quarkupy/commit/ef63563e7b3169be4ac309a6a28d0d04892128c1))
* **ci:** only run for pushes and fork pull requests ([924eda9](https://github.com/quarklabsai/quarkupy/commit/924eda9bd3adb102a2bf72b7299d0f5be165cdea))
* **docs:** grammar improvements ([873f20f](https://github.com/quarklabsai/quarkupy/commit/873f20ffeebd635de765ff3e0149485344c23bc9))
* **docs:** grammar improvements ([b29acee](https://github.com/quarklabsai/quarkupy/commit/b29acee0641e54d865ee832576bb43735648176e))
* **docs:** remove reference to rye shell ([4b78f0a](https://github.com/quarklabsai/quarkupy/commit/4b78f0a8fb034cce834c8403b1382ccf6bc57363))
* **docs:** remove reference to rye shell ([689c32e](https://github.com/quarklabsai/quarkupy/commit/689c32e1df9809165339e333d0ed4010bdea59e3))
* **internal:** codegen related update ([f22e4e0](https://github.com/quarklabsai/quarkupy/commit/f22e4e092a5bafb1dce172316a792de1630ad6f4))
* **internal:** codegen related update ([c631505](https://github.com/quarklabsai/quarkupy/commit/c631505aa4fa0fa4f66bd1de502245c748e2c63a))
* **internal:** codegen related update ([2a3dc39](https://github.com/quarklabsai/quarkupy/commit/2a3dc39c6d39134618bb8004e6f464d96541989c))
* **internal:** update conftest.py ([2abcf20](https://github.com/quarklabsai/quarkupy/commit/2abcf207e235b2f80cb06bdcf210d2fceaca2ab9))
* **internal:** update conftest.py ([92a1830](https://github.com/quarklabsai/quarkupy/commit/92a18303f7be42b9c91b8a436c80cdc13ceaabba))
* **internal:** version bump ([1214699](https://github.com/quarklabsai/quarkupy/commit/121469908d9b396c2c77e607e621622c6daa9c76))
* **internal:** version bump ([a33701d](https://github.com/quarklabsai/quarkupy/commit/a33701d0d88d9d8f175f17d03771770255c42558))
* **internal:** version bump ([a4c4869](https://github.com/quarklabsai/quarkupy/commit/a4c4869cef269cb61bc159d69b2c395300b4f6c0))
* **internal:** version bump ([84b025b](https://github.com/quarklabsai/quarkupy/commit/84b025bd1fc4c593fc1b436a7bcdfaa3ce71548e))
* **internal:** version bump ([9c2c5a3](https://github.com/quarklabsai/quarkupy/commit/9c2c5a35369db16e4c3d7c51d53f5c70debf57b5))
* **internal:** version bump ([7657520](https://github.com/quarklabsai/quarkupy/commit/7657520367669a078e99414c3d7cefd788dbffbf))
* **internal:** version bump ([7f911cf](https://github.com/quarklabsai/quarkupy/commit/7f911cf9d92e2f24a1fdaf2a014cd00458d40054))
* **internal:** version bump ([c8ea26f](https://github.com/quarklabsai/quarkupy/commit/c8ea26fb359bd0b36a4c142691444a401817b6c4))
* **internal:** version bump ([7e7387e](https://github.com/quarklabsai/quarkupy/commit/7e7387ec734a2da79868624681cca8ae92d8b15b))
* **internal:** version bump ([af77b51](https://github.com/quarklabsai/quarkupy/commit/af77b515d597074d566534bb06b4f6813bdba3c7))
* **internal:** version bump ([308133f](https://github.com/quarklabsai/quarkupy/commit/308133f4c716736634b09da4d85a73aa7512ac44))
* **internal:** version bump ([9ba395a](https://github.com/quarklabsai/quarkupy/commit/9ba395a725407dbfb018a66b45ee751cbc554b41))
* **internal:** version bump ([c170209](https://github.com/quarklabsai/quarkupy/commit/c170209d16053209b356b6ce5b508a3cc2c7cfef))
* **internal:** version bump ([23fdd40](https://github.com/quarklabsai/quarkupy/commit/23fdd40516821e24854a7b804133f27064999114))
* **internal:** version bump ([2c7f708](https://github.com/quarklabsai/quarkupy/commit/2c7f7083eb9da9a88df2a2d99a0aba9c9e7d7b2e))
* **internal:** version bump ([086845f](https://github.com/quarklabsai/quarkupy/commit/086845f6f267ec7c96ebfa57128115ed3a32ca9d))
* **internal:** version bump ([bbb5f8b](https://github.com/quarklabsai/quarkupy/commit/bbb5f8bc26d41504437a93ffa16b652b55a49ea3))
* **internal:** version bump ([b4302a2](https://github.com/quarklabsai/quarkupy/commit/b4302a29726deaef64ec1f89a5b507efc5308a57))
* **readme:** update badges ([36cd0d6](https://github.com/quarklabsai/quarkupy/commit/36cd0d66ec0469ad7bba2208a35b833886112287))
* **readme:** update badges ([c39ab92](https://github.com/quarklabsai/quarkupy/commit/c39ab9241a74118bd94863325182661d1f0d7201))
* **tests:** add tests for httpx client instantiation & proxies ([70449b7](https://github.com/quarklabsai/quarkupy/commit/70449b7b03e9f2dbd16dde0324356244a3b0885f))
* **tests:** add tests for httpx client instantiation & proxies ([88da7d4](https://github.com/quarklabsai/quarkupy/commit/88da7d4a0d5586f4210eb9d5eb6772af0f534f0c))
* **tests:** run tests in parallel ([f4168a9](https://github.com/quarklabsai/quarkupy/commit/f4168a9aa22cf9832db26d787fb4ac37c42d6f8e))
* **tests:** run tests in parallel ([4d0d55c](https://github.com/quarklabsai/quarkupy/commit/4d0d55cab273a0a5f0b248a243c3757bd2906676))
* **tests:** skip some failing tests on the latest python versions ([016b316](https://github.com/quarklabsai/quarkupy/commit/016b316aa96fe5e331972533d30f4a14319e8a28))
* **tests:** skip some failing tests on the latest python versions ([f045bb9](https://github.com/quarklabsai/quarkupy/commit/f045bb9e3f0dc100d2a6e4d74b57873889bd91a9))
* update SDK settings ([3f44264](https://github.com/quarklabsai/quarkupy/commit/3f4426499cb059e4a5d80d50e2611659dfd40b1b))
* update SDK settings ([48097df](https://github.com/quarklabsai/quarkupy/commit/48097dfa7934e79a3db6c7351453fe5904b279ef))
* update SDK settings ([37e0093](https://github.com/quarklabsai/quarkupy/commit/37e00935a08e2927af668f199d5aa6369c5a637f))
* update SDK settings ([082f94f](https://github.com/quarklabsai/quarkupy/commit/082f94f302fb09c1a8202219474ccc57e7f826ca))
* update SDK settings ([08bfe19](https://github.com/quarklabsai/quarkupy/commit/08bfe195ca483859ebf8164f360f11e8fce069d2))
* update SDK settings ([583e218](https://github.com/quarklabsai/quarkupy/commit/583e21833e16811a5be0d78512d212193439e8e8))
* update SDK settings ([840f1b7](https://github.com/quarklabsai/quarkupy/commit/840f1b7133d72d35dbba74b596c24688135d3a02))
* update SDK settings ([022b04c](https://github.com/quarklabsai/quarkupy/commit/022b04c101922b02a40870f6af171694b7d1efff))
* update SDK settings ([5af301c](https://github.com/quarklabsai/quarkupy/commit/5af301cb72ee66e8e2bfe96e183d7c743636858f))
* update SDK settings ([0a9d510](https://github.com/quarklabsai/quarkupy/commit/0a9d5102eae69e866d155744c7d49731b100ecee))
* update SDK settings ([e6e5eb3](https://github.com/quarklabsai/quarkupy/commit/e6e5eb3959d938f093578eef3dbff3baaaa04efe))
* update SDK settings ([13a12ac](https://github.com/quarklabsai/quarkupy/commit/13a12ac5bf071ac7e7b6b8ae65bb65767bcab8d2))
* update SDK settings ([ca84d3e](https://github.com/quarklabsai/quarkupy/commit/ca84d3ee3416298bc95f33a2c8f064bd516f6d78))
* update SDK settings ([b50752b](https://github.com/quarklabsai/quarkupy/commit/b50752bac734657606efaa400017b968828a7c94))
* update SDK settings ([07b864b](https://github.com/quarklabsai/quarkupy/commit/07b864b729b04d7130f182fc482eb3c5a913ec86))
* update SDK settings ([c701cfa](https://github.com/quarklabsai/quarkupy/commit/c701cfa3a75d4c5dd70be579bcb96b683fed1dd0))
* update SDK settings ([1519f54](https://github.com/quarklabsai/quarkupy/commit/1519f54e6709bf4d1385b468f39ea00c2e4a3eed))
* update SDK settings ([d3b18bc](https://github.com/quarklabsai/quarkupy/commit/d3b18bc83bd5af999ce0447c348675262ffb23c9))
* update SDK settings ([ce93b52](https://github.com/quarklabsai/quarkupy/commit/ce93b52208a3e03850e0e621863cf6da88122900))
* update SDK settings ([b1c5dc7](https://github.com/quarklabsai/quarkupy/commit/b1c5dc7e10b6902b2fef0c2f56cd9c08c46249b5))
* update SDK settings ([6ad2512](https://github.com/quarklabsai/quarkupy/commit/6ad25128e5d3db9b449f24ac4b3a8176de42f1b0))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([f7cd43d](https://github.com/quarklabsai/quarkupy/commit/f7cd43d9ff89e4408c9c1b5d07e870d3eac4c71b))
* **client:** fix httpx.Timeout documentation reference ([cbe44c5](https://github.com/quarklabsai/quarkupy/commit/cbe44c5c17fb1dae0f451fb2ef2609248d1f89ed))

## 0.4.0 (2025-07-03)

Full Changelog: [v0.3.2...v0.4.0](https://github.com/quarklabsai/quarkupy/compare/v0.3.2...v0.4.0)

### Features

* **api:** api update ([4a46252](https://github.com/quarklabsai/quarkupy/commit/4a4625295183ec191ee6c812aef518a3e629f658))
* **api:** api update ([18a7b78](https://github.com/quarklabsai/quarkupy/commit/18a7b78df099a71b3b724a253a51d8d880f8a201))
* **api:** manual updates ([fcf62a1](https://github.com/quarklabsai/quarkupy/commit/fcf62a15c59f6ac3bdca031d8057f0803f3e6004))
* **api:** manual updates ([3ca585d](https://github.com/quarklabsai/quarkupy/commit/3ca585d7a0c447f4e3ef9c0a80ad2ac153f18688))
* **api:** manual updates ([d7353af](https://github.com/quarklabsai/quarkupy/commit/d7353af1348f1a29c37951f5383b28f8c8fbbe99))


### Chores

* update SDK settings ([3f44264](https://github.com/quarklabsai/quarkupy/commit/3f4426499cb059e4a5d80d50e2611659dfd40b1b))
* update SDK settings ([48097df](https://github.com/quarklabsai/quarkupy/commit/48097dfa7934e79a3db6c7351453fe5904b279ef))

## 0.3.2 (2025-07-02)

Full Changelog: [v0.3.1...v0.3.2](https://github.com/quarklabsai/quarkupy/compare/v0.3.1...v0.3.2)

### Chores

* **ci:** change upload type ([e539e42](https://github.com/quarklabsai/quarkupy/commit/e539e423c65f9b4e422687996d8fea6a07706ca0))

## 0.3.1 (2025-07-01)

Full Changelog: [v0.3.0...v0.3.1](https://github.com/quarklabsai/quarkupy/compare/v0.3.0...v0.3.1)

## 0.3.0 (2025-07-01)

Full Changelog: [v0.2.1...v0.3.0](https://github.com/quarklabsai/quarkupy/compare/v0.2.1...v0.3.0)

### Features

* **api:** manual updates ([a30285b](https://github.com/quarklabsai/quarkupy/commit/a30285b216b49f045a7a6b7155055c3d596dca3a))

## 0.2.1 (2025-06-30)

Full Changelog: [v0.2.0...v0.2.1](https://github.com/quarklabsai/quarkupy/compare/v0.2.0...v0.2.1)

### Bug Fixes

* **ci:** correct conditional ([c800acf](https://github.com/quarklabsai/quarkupy/commit/c800acf52213d93f6b0ccb4ec7465dd9f2eb47ea))


### Chores

* **internal:** codegen related update ([f22e4e0](https://github.com/quarklabsai/quarkupy/commit/f22e4e092a5bafb1dce172316a792de1630ad6f4))

## 0.2.0 (2025-06-29)

Full Changelog: [v0.1.0...v0.2.0](https://github.com/quarklabsai/quarkupy/compare/v0.1.0...v0.2.0)

### Features

* **api:** api update ([4e6f1bb](https://github.com/quarklabsai/quarkupy/commit/4e6f1bb88fecc27e49ef876333d4c25661cd7e95))
* **api:** api update ([4cf4a7c](https://github.com/quarklabsai/quarkupy/commit/4cf4a7c7344e017086ccd8ef3d6f0eb8c946eca0))
* **api:** manual updates ([cebf187](https://github.com/quarklabsai/quarkupy/commit/cebf1871a5d558c402a82a53a5f191d64cca26be))
* **api:** manual updates ([1ff9e9b](https://github.com/quarklabsai/quarkupy/commit/1ff9e9b9fdaa0851439208a2cf9942dae24902cf))


### Chores

* **internal:** version bump ([1214699](https://github.com/quarklabsai/quarkupy/commit/121469908d9b396c2c77e607e621622c6daa9c76))

## 0.1.0 (2025-06-28)

Full Changelog: [v0.1.0-alpha.15...v0.1.0](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.15...v0.1.0)

### Features

* **api:** api update ([3b38924](https://github.com/quarklabsai/quarkupy/commit/3b389247a7f06a2755ce0552b4326a606bbbef72))
* **api:** manual updates ([b454144](https://github.com/quarklabsai/quarkupy/commit/b4541448ad075850f3a611473a3b92946178208e))
* **api:** manual updates ([4c40293](https://github.com/quarklabsai/quarkupy/commit/4c402933357a18564fe1a28bf8b2ebb855491ee6))
* **api:** manual updates ([0572947](https://github.com/quarklabsai/quarkupy/commit/0572947e2df7933814d7d57ab4a28243c7e7d9f2))
* **api:** manual updates ([e7cf93f](https://github.com/quarklabsai/quarkupy/commit/e7cf93f15a9eb037688ff46e20e706bfd0d7facc))
* **api:** manual updates ([d8f2caf](https://github.com/quarklabsai/quarkupy/commit/d8f2caf0e7f50049c8c4243fbffe5561ebc196ab))


### Chores

* **ci:** only run for pushes and fork pull requests ([924eda9](https://github.com/quarklabsai/quarkupy/commit/924eda9bd3adb102a2bf72b7299d0f5be165cdea))
* **internal:** version bump ([a33701d](https://github.com/quarklabsai/quarkupy/commit/a33701d0d88d9d8f175f17d03771770255c42558))
* **internal:** version bump ([a4c4869](https://github.com/quarklabsai/quarkupy/commit/a4c4869cef269cb61bc159d69b2c395300b4f6c0))
* update SDK settings ([37e0093](https://github.com/quarklabsai/quarkupy/commit/37e00935a08e2927af668f199d5aa6369c5a637f))
* update SDK settings ([082f94f](https://github.com/quarklabsai/quarkupy/commit/082f94f302fb09c1a8202219474ccc57e7f826ca))
* update SDK settings ([08bfe19](https://github.com/quarklabsai/quarkupy/commit/08bfe195ca483859ebf8164f360f11e8fce069d2))

## 0.1.0-alpha.15 (2025-06-28)

Full Changelog: [v0.1.0-alpha.14...v0.1.0-alpha.15](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.14...v0.1.0-alpha.15)

### Features

* **api:** api update ([65aeb10](https://github.com/quarklabsai/quarkupy/commit/65aeb10ab7fb463f83587f612b498fed11d81825))
* **api:** update via SDK Studio ([912d144](https://github.com/quarklabsai/quarkupy/commit/912d144d2eb4d3fdf03d3173acde3f7ab6714753))


### Chores

* **internal:** version bump ([84b025b](https://github.com/quarklabsai/quarkupy/commit/84b025bd1fc4c593fc1b436a7bcdfaa3ce71548e))
* **internal:** version bump ([9c2c5a3](https://github.com/quarklabsai/quarkupy/commit/9c2c5a35369db16e4c3d7c51d53f5c70debf57b5))
* **internal:** version bump ([7657520](https://github.com/quarklabsai/quarkupy/commit/7657520367669a078e99414c3d7cefd788dbffbf))
* **internal:** version bump ([7f911cf](https://github.com/quarklabsai/quarkupy/commit/7f911cf9d92e2f24a1fdaf2a014cd00458d40054))

## 0.1.0 (2025-06-28)

Full Changelog: [v0.1.0-alpha.14...v0.1.0](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.14...v0.1.0)

### Features

* **api:** update via SDK Studio ([903b816](https://github.com/quarklabsai/quarkupy/commit/903b8160e4bababaf81a39c79c10b39e6b1cd260))
* **api:** update via SDK Studio ([acbb858](https://github.com/quarklabsai/quarkupy/commit/acbb858b104993cbb388b3cabcb8de0131b3bd95))


### Bug Fixes

* **ci:** release-doctor — report correct token name ([a97a2b2](https://github.com/quarklabsai/quarkupy/commit/a97a2b2b8a802f65fb46cb14b2a4975644e7e3ff))


### Chores

* **internal:** version bump ([c8ea26f](https://github.com/quarklabsai/quarkupy/commit/c8ea26fb359bd0b36a4c142691444a401817b6c4))
* update SDK settings ([583e218](https://github.com/quarklabsai/quarkupy/commit/583e21833e16811a5be0d78512d212193439e8e8))
* update SDK settings ([840f1b7](https://github.com/quarklabsai/quarkupy/commit/840f1b7133d72d35dbba74b596c24688135d3a02))

## 0.1.0-alpha.14 (2025-06-27)

Full Changelog: [v0.1.0-alpha.13...v0.1.0-alpha.14](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.13...v0.1.0-alpha.14)

### Chores

* **internal:** version bump ([7e7387e](https://github.com/quarklabsai/quarkupy/commit/7e7387ec734a2da79868624681cca8ae92d8b15b))

## 0.1.0-alpha.13 (2025-06-27)

Full Changelog: [v0.1.0-alpha.12...v0.1.0-alpha.13](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.12...v0.1.0-alpha.13)

### Features

* **api:** update via SDK Studio ([c91f274](https://github.com/quarklabsai/quarkupy/commit/c91f2746576e4d60e14923631bfde39f372f8c56))

## 0.1.0-alpha.12 (2025-06-27)

Full Changelog: [v0.1.0-alpha.11...v0.1.0-alpha.12](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.11...v0.1.0-alpha.12)

### Features

* **api:** update via SDK Studio ([80e74f9](https://github.com/quarklabsai/quarkupy/commit/80e74f9daccc7b4befefd7bf61ba853cb2083313))
* **api:** update via SDK Studio ([c9c87e0](https://github.com/quarklabsai/quarkupy/commit/c9c87e0542f6dae7e089fb2cb6d618dc2a3f38a0))

## 0.1.0-alpha.11 (2025-06-27)

Full Changelog: [v0.1.0-alpha.10...v0.1.0-alpha.11](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.10...v0.1.0-alpha.11)

### Features

* **api:** update via SDK Studio ([358d5ef](https://github.com/quarklabsai/quarkupy/commit/358d5ef9674df1d17585ce66364e18b7561e7786))
* **api:** update via SDK Studio ([6f03f44](https://github.com/quarklabsai/quarkupy/commit/6f03f44bd16c50e2c0fb2088acae04223f8a4ae0))
* **api:** update via SDK Studio ([38179db](https://github.com/quarklabsai/quarkupy/commit/38179db096ad24d8ae2e321dc202d3870b6736df))
* **api:** update via SDK Studio ([b676a9f](https://github.com/quarklabsai/quarkupy/commit/b676a9fb4eb5f38ee6a9a65f6f3b442f9d83bddc))
* **api:** update via SDK Studio ([e265611](https://github.com/quarklabsai/quarkupy/commit/e265611a9062a340533cfef1f1c26940b22c7731))
* **api:** update via SDK Studio ([f537948](https://github.com/quarklabsai/quarkupy/commit/f53794812dee9fe02b59f63cb6b998b7806264c4))
* **api:** update via SDK Studio ([1d53583](https://github.com/quarklabsai/quarkupy/commit/1d53583d718cf706528af2ce696dc9946185a911))
* **api:** update via SDK Studio ([d721d48](https://github.com/quarklabsai/quarkupy/commit/d721d484324611932ff43c6028d4a1702382bd7a))
* **api:** update via SDK Studio ([a560faf](https://github.com/quarklabsai/quarkupy/commit/a560fafe705bfae919f759df6e08efc1b792fb2b))
* **api:** update via SDK Studio ([a679452](https://github.com/quarklabsai/quarkupy/commit/a679452b0cd3ce615b83118353e2b527609afabf))
* **api:** update via SDK Studio ([810ca9c](https://github.com/quarklabsai/quarkupy/commit/810ca9c0cc1b49aecae30f006549f85078415758))
* **api:** update via SDK Studio ([3a26651](https://github.com/quarklabsai/quarkupy/commit/3a26651d3d5cd3aa61570347b08440ddb905bc2b))
* **api:** update via SDK Studio ([39c6187](https://github.com/quarklabsai/quarkupy/commit/39c6187398ee2737ae29e532585c704ea35ce3f3))
* **api:** update via SDK Studio ([79335b1](https://github.com/quarklabsai/quarkupy/commit/79335b1cce9440fc6bc347b512311fa208970d47))
* **api:** update via SDK Studio ([76c3baf](https://github.com/quarklabsai/quarkupy/commit/76c3baf3578741eceac1747b6998c7ed4201b502))
* **api:** update via SDK Studio ([e673847](https://github.com/quarklabsai/quarkupy/commit/e673847f2d9e49ccf8d9b56dc96cb1acd0806550))
* **api:** update via SDK Studio ([aad1e18](https://github.com/quarklabsai/quarkupy/commit/aad1e18f69d93775d00b2e06ff0728b1865d3bec))
* **api:** update via SDK Studio ([7621aef](https://github.com/quarklabsai/quarkupy/commit/7621aefae5292237cd011982846f0aba777604cf))
* **api:** update via SDK Studio ([3a4b01f](https://github.com/quarklabsai/quarkupy/commit/3a4b01f1fe2d6ffee011154eff8d422d0c1515c8))
* **api:** update via SDK Studio ([7acd65d](https://github.com/quarklabsai/quarkupy/commit/7acd65dcafb9250f7fe7b1c1cac276cde7d52ead))
* **api:** update via SDK Studio ([fd901e8](https://github.com/quarklabsai/quarkupy/commit/fd901e86b4b6db1b144874659eae1dc685c05883))
* **api:** update via SDK Studio ([9f6e3f1](https://github.com/quarklabsai/quarkupy/commit/9f6e3f18e63f5ad3647d224c94f34126658715bc))
* **api:** update via SDK Studio ([f3ae15e](https://github.com/quarklabsai/quarkupy/commit/f3ae15eaf00460af0d2e1ddaef4f2bb2eb033796))
* **api:** update via SDK Studio ([f501d36](https://github.com/quarklabsai/quarkupy/commit/f501d3699c58c922b4ff98c12d10acb21ba9f252))
* **api:** update via SDK Studio ([3b231cb](https://github.com/quarklabsai/quarkupy/commit/3b231cbca70dcec2f6c2ba2e403007f25692cb12))
* **api:** update via SDK Studio ([5ca50d3](https://github.com/quarklabsai/quarkupy/commit/5ca50d3a9fa03ca27d917edae215af631082d6ec))
* **api:** update via SDK Studio ([8cb2c16](https://github.com/quarklabsai/quarkupy/commit/8cb2c167245d302e31db694121dbb877b59d26ab))
* **api:** update via SDK Studio ([57af12e](https://github.com/quarklabsai/quarkupy/commit/57af12e5c162607b2aa15c143a766714dc187328))
* **api:** update via SDK Studio ([d529592](https://github.com/quarklabsai/quarkupy/commit/d5295926809aff8159cc6478b1c358daaf11be91))
* **api:** update via SDK Studio ([49f0a79](https://github.com/quarklabsai/quarkupy/commit/49f0a79a0cd1b5082c8c32d4407ae86e37445730))
* **api:** update via SDK Studio ([f01de4a](https://github.com/quarklabsai/quarkupy/commit/f01de4ad9488325d6c722c19e42fe17238faa9ab))
* **api:** update via SDK Studio ([4626c10](https://github.com/quarklabsai/quarkupy/commit/4626c108de77e3aa80d2023c7bc901271a06ad22))
* **client:** add follow_redirects request option ([71b858c](https://github.com/quarklabsai/quarkupy/commit/71b858c1b02a223e69959a469d823fa310583653))
* **client:** add follow_redirects request option ([1a739c4](https://github.com/quarklabsai/quarkupy/commit/1a739c45df84b33af102669d2cff91528828f7d3))
* **client:** add support for aiohttp ([d6a3717](https://github.com/quarklabsai/quarkupy/commit/d6a37178c22f84c44c3140872ce68ec1155d2105))
* **client:** add support for aiohttp ([043e887](https://github.com/quarklabsai/quarkupy/commit/043e887eb2ecf7e1db9349d16f5ccd636a06c312))


### Bug Fixes

* **client:** correctly parse binary response | stream ([285883d](https://github.com/quarklabsai/quarkupy/commit/285883ddf47441d06667083d3ec8a3da571c21d2))
* **client:** correctly parse binary response | stream ([e0df280](https://github.com/quarklabsai/quarkupy/commit/e0df2802cbab68b948e989bc3e00abf4b2ec2bca))
* **docs/api:** remove references to nonexistent types ([52601ec](https://github.com/quarklabsai/quarkupy/commit/52601ec2704a3f0794ae3db45a4f56898a929ce4))
* **docs/api:** remove references to nonexistent types ([caa3528](https://github.com/quarklabsai/quarkupy/commit/caa352854e7a0ae177603b23847d2e120676a3b5))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([db499ff](https://github.com/quarklabsai/quarkupy/commit/db499ff1d0e8011219d2f14642e3ee4fb799340c))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([7497832](https://github.com/quarklabsai/quarkupy/commit/74978322373d54be27322d54a057986b091693c6))


### Chores

* **ci:** enable for pull requests ([3a27142](https://github.com/quarklabsai/quarkupy/commit/3a271423b8682268be4816ed37b956469e228532))
* **ci:** enable for pull requests ([ef63563](https://github.com/quarklabsai/quarkupy/commit/ef63563e7b3169be4ac309a6a28d0d04892128c1))
* **docs:** grammar improvements ([873f20f](https://github.com/quarklabsai/quarkupy/commit/873f20ffeebd635de765ff3e0149485344c23bc9))
* **docs:** grammar improvements ([b29acee](https://github.com/quarklabsai/quarkupy/commit/b29acee0641e54d865ee832576bb43735648176e))
* **docs:** remove reference to rye shell ([4b78f0a](https://github.com/quarklabsai/quarkupy/commit/4b78f0a8fb034cce834c8403b1382ccf6bc57363))
* **docs:** remove reference to rye shell ([689c32e](https://github.com/quarklabsai/quarkupy/commit/689c32e1df9809165339e333d0ed4010bdea59e3))
* **internal:** codegen related update ([c631505](https://github.com/quarklabsai/quarkupy/commit/c631505aa4fa0fa4f66bd1de502245c748e2c63a))
* **internal:** codegen related update ([2a3dc39](https://github.com/quarklabsai/quarkupy/commit/2a3dc39c6d39134618bb8004e6f464d96541989c))
* **internal:** update conftest.py ([2abcf20](https://github.com/quarklabsai/quarkupy/commit/2abcf207e235b2f80cb06bdcf210d2fceaca2ab9))
* **internal:** update conftest.py ([92a1830](https://github.com/quarklabsai/quarkupy/commit/92a18303f7be42b9c91b8a436c80cdc13ceaabba))
* **internal:** version bump ([af77b51](https://github.com/quarklabsai/quarkupy/commit/af77b515d597074d566534bb06b4f6813bdba3c7))
* **internal:** version bump ([308133f](https://github.com/quarklabsai/quarkupy/commit/308133f4c716736634b09da4d85a73aa7512ac44))
* **internal:** version bump ([9ba395a](https://github.com/quarklabsai/quarkupy/commit/9ba395a725407dbfb018a66b45ee751cbc554b41))
* **internal:** version bump ([c170209](https://github.com/quarklabsai/quarkupy/commit/c170209d16053209b356b6ce5b508a3cc2c7cfef))
* **internal:** version bump ([23fdd40](https://github.com/quarklabsai/quarkupy/commit/23fdd40516821e24854a7b804133f27064999114))
* **internal:** version bump ([2c7f708](https://github.com/quarklabsai/quarkupy/commit/2c7f7083eb9da9a88df2a2d99a0aba9c9e7d7b2e))
* **internal:** version bump ([086845f](https://github.com/quarklabsai/quarkupy/commit/086845f6f267ec7c96ebfa57128115ed3a32ca9d))
* **internal:** version bump ([bbb5f8b](https://github.com/quarklabsai/quarkupy/commit/bbb5f8bc26d41504437a93ffa16b652b55a49ea3))
* **internal:** version bump ([b4302a2](https://github.com/quarklabsai/quarkupy/commit/b4302a29726deaef64ec1f89a5b507efc5308a57))
* **readme:** update badges ([36cd0d6](https://github.com/quarklabsai/quarkupy/commit/36cd0d66ec0469ad7bba2208a35b833886112287))
* **readme:** update badges ([c39ab92](https://github.com/quarklabsai/quarkupy/commit/c39ab9241a74118bd94863325182661d1f0d7201))
* **tests:** add tests for httpx client instantiation & proxies ([70449b7](https://github.com/quarklabsai/quarkupy/commit/70449b7b03e9f2dbd16dde0324356244a3b0885f))
* **tests:** add tests for httpx client instantiation & proxies ([88da7d4](https://github.com/quarklabsai/quarkupy/commit/88da7d4a0d5586f4210eb9d5eb6772af0f534f0c))
* **tests:** run tests in parallel ([f4168a9](https://github.com/quarklabsai/quarkupy/commit/f4168a9aa22cf9832db26d787fb4ac37c42d6f8e))
* **tests:** run tests in parallel ([4d0d55c](https://github.com/quarklabsai/quarkupy/commit/4d0d55cab273a0a5f0b248a243c3757bd2906676))
* **tests:** skip some failing tests on the latest python versions ([016b316](https://github.com/quarklabsai/quarkupy/commit/016b316aa96fe5e331972533d30f4a14319e8a28))
* **tests:** skip some failing tests on the latest python versions ([f045bb9](https://github.com/quarklabsai/quarkupy/commit/f045bb9e3f0dc100d2a6e4d74b57873889bd91a9))
* update SDK settings ([022b04c](https://github.com/quarklabsai/quarkupy/commit/022b04c101922b02a40870f6af171694b7d1efff))
* update SDK settings ([5af301c](https://github.com/quarklabsai/quarkupy/commit/5af301cb72ee66e8e2bfe96e183d7c743636858f))
* update SDK settings ([0a9d510](https://github.com/quarklabsai/quarkupy/commit/0a9d5102eae69e866d155744c7d49731b100ecee))
* update SDK settings ([e6e5eb3](https://github.com/quarklabsai/quarkupy/commit/e6e5eb3959d938f093578eef3dbff3baaaa04efe))
* update SDK settings ([13a12ac](https://github.com/quarklabsai/quarkupy/commit/13a12ac5bf071ac7e7b6b8ae65bb65767bcab8d2))
* update SDK settings ([ca84d3e](https://github.com/quarklabsai/quarkupy/commit/ca84d3ee3416298bc95f33a2c8f064bd516f6d78))
* update SDK settings ([b50752b](https://github.com/quarklabsai/quarkupy/commit/b50752bac734657606efaa400017b968828a7c94))
* update SDK settings ([07b864b](https://github.com/quarklabsai/quarkupy/commit/07b864b729b04d7130f182fc482eb3c5a913ec86))
* update SDK settings ([c701cfa](https://github.com/quarklabsai/quarkupy/commit/c701cfa3a75d4c5dd70be579bcb96b683fed1dd0))
* update SDK settings ([1519f54](https://github.com/quarklabsai/quarkupy/commit/1519f54e6709bf4d1385b468f39ea00c2e4a3eed))
* update SDK settings ([d3b18bc](https://github.com/quarklabsai/quarkupy/commit/d3b18bc83bd5af999ce0447c348675262ffb23c9))
* update SDK settings ([ce93b52](https://github.com/quarklabsai/quarkupy/commit/ce93b52208a3e03850e0e621863cf6da88122900))
* update SDK settings ([b1c5dc7](https://github.com/quarklabsai/quarkupy/commit/b1c5dc7e10b6902b2fef0c2f56cd9c08c46249b5))
* update SDK settings ([6ad2512](https://github.com/quarklabsai/quarkupy/commit/6ad25128e5d3db9b449f24ac4b3a8176de42f1b0))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([f7cd43d](https://github.com/quarklabsai/quarkupy/commit/f7cd43d9ff89e4408c9c1b5d07e870d3eac4c71b))
* **client:** fix httpx.Timeout documentation reference ([cbe44c5](https://github.com/quarklabsai/quarkupy/commit/cbe44c5c17fb1dae0f451fb2ef2609248d1f89ed))

## 0.1.0-alpha.10 (2025-06-26)

Full Changelog: [v0.1.0-alpha.9...v0.1.0-alpha.10](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.9...v0.1.0-alpha.10)

## 0.1.0-alpha.9 (2025-06-26)

Full Changelog: [v0.1.0-alpha.8...v0.1.0-alpha.9](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.8...v0.1.0-alpha.9)

### Features

* **api:** update via SDK Studio ([358d5ef](https://github.com/quarklabsai/quarkupy/commit/358d5ef9674df1d17585ce66364e18b7561e7786))
* **api:** update via SDK Studio ([6f03f44](https://github.com/quarklabsai/quarkupy/commit/6f03f44bd16c50e2c0fb2088acae04223f8a4ae0))

## 0.1.0-alpha.8 (2025-06-26)

Full Changelog: [v0.1.0-alpha.7...v0.1.0-alpha.8](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.7...v0.1.0-alpha.8)

### Features

* **api:** update via SDK Studio ([38179db](https://github.com/quarklabsai/quarkupy/commit/38179db096ad24d8ae2e321dc202d3870b6736df))
* **api:** update via SDK Studio ([b676a9f](https://github.com/quarklabsai/quarkupy/commit/b676a9fb4eb5f38ee6a9a65f6f3b442f9d83bddc))


### Chores

* **internal:** version bump ([308133f](https://github.com/quarklabsai/quarkupy/commit/308133f4c716736634b09da4d85a73aa7512ac44))

## 0.1.0-alpha.7 (2025-06-26)

Full Changelog: [v0.1.0-alpha.6...v0.1.0-alpha.7](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.6...v0.1.0-alpha.7)

### Features

* **api:** update via SDK Studio ([1d53583](https://github.com/quarklabsai/quarkupy/commit/1d53583d718cf706528af2ce696dc9946185a911))
* **api:** update via SDK Studio ([a560faf](https://github.com/quarklabsai/quarkupy/commit/a560fafe705bfae919f759df6e08efc1b792fb2b))
* **api:** update via SDK Studio ([810ca9c](https://github.com/quarklabsai/quarkupy/commit/810ca9c0cc1b49aecae30f006549f85078415758))
* **client:** add support for aiohttp ([d6a3717](https://github.com/quarklabsai/quarkupy/commit/d6a37178c22f84c44c3140872ce68ec1155d2105))


### Bug Fixes

* **client:** correctly parse binary response | stream ([285883d](https://github.com/quarklabsai/quarkupy/commit/285883ddf47441d06667083d3ec8a3da571c21d2))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([db499ff](https://github.com/quarklabsai/quarkupy/commit/db499ff1d0e8011219d2f14642e3ee4fb799340c))


### Chores

* **ci:** enable for pull requests ([3a27142](https://github.com/quarklabsai/quarkupy/commit/3a271423b8682268be4816ed37b956469e228532))
* **internal:** update conftest.py ([2abcf20](https://github.com/quarklabsai/quarkupy/commit/2abcf207e235b2f80cb06bdcf210d2fceaca2ab9))
* **readme:** update badges ([36cd0d6](https://github.com/quarklabsai/quarkupy/commit/36cd0d66ec0469ad7bba2208a35b833886112287))
* **tests:** add tests for httpx client instantiation & proxies ([70449b7](https://github.com/quarklabsai/quarkupy/commit/70449b7b03e9f2dbd16dde0324356244a3b0885f))
* **tests:** run tests in parallel ([f4168a9](https://github.com/quarklabsai/quarkupy/commit/f4168a9aa22cf9832db26d787fb4ac37c42d6f8e))
* **tests:** skip some failing tests on the latest python versions ([016b316](https://github.com/quarklabsai/quarkupy/commit/016b316aa96fe5e331972533d30f4a14319e8a28))
* update SDK settings ([022b04c](https://github.com/quarklabsai/quarkupy/commit/022b04c101922b02a40870f6af171694b7d1efff))
* update SDK settings ([0a9d510](https://github.com/quarklabsai/quarkupy/commit/0a9d5102eae69e866d155744c7d49731b100ecee))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([f7cd43d](https://github.com/quarklabsai/quarkupy/commit/f7cd43d9ff89e4408c9c1b5d07e870d3eac4c71b))

## 0.1.0-alpha.6 (2025-06-04)

Full Changelog: [v0.1.0-alpha.5...v0.1.0-alpha.6](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.5...v0.1.0-alpha.6)

### Features

* **api:** update via SDK Studio ([39c6187](https://github.com/quarklabsai/quarkupy/commit/39c6187398ee2737ae29e532585c704ea35ce3f3))
* **api:** update via SDK Studio ([76c3baf](https://github.com/quarklabsai/quarkupy/commit/76c3baf3578741eceac1747b6998c7ed4201b502))
* **api:** update via SDK Studio ([aad1e18](https://github.com/quarklabsai/quarkupy/commit/aad1e18f69d93775d00b2e06ff0728b1865d3bec))
* **api:** update via SDK Studio ([3a4b01f](https://github.com/quarklabsai/quarkupy/commit/3a4b01f1fe2d6ffee011154eff8d422d0c1515c8))
* **api:** update via SDK Studio ([fd901e8](https://github.com/quarklabsai/quarkupy/commit/fd901e86b4b6db1b144874659eae1dc685c05883))


### Chores

* update SDK settings ([13a12ac](https://github.com/quarklabsai/quarkupy/commit/13a12ac5bf071ac7e7b6b8ae65bb65767bcab8d2))
* update SDK settings ([b50752b](https://github.com/quarklabsai/quarkupy/commit/b50752bac734657606efaa400017b968828a7c94))

## 0.1.0-alpha.5 (2025-06-04)

Full Changelog: [v0.1.0-alpha.4...v0.1.0-alpha.5](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.4...v0.1.0-alpha.5)

### Features

* **api:** update via SDK Studio ([f3ae15e](https://github.com/quarklabsai/quarkupy/commit/f3ae15eaf00460af0d2e1ddaef4f2bb2eb033796))

## 0.1.0-alpha.4 (2025-06-04)

Full Changelog: [v0.1.0-alpha.3...v0.1.0-alpha.4](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.3...v0.1.0-alpha.4)

### Features

* **api:** update via SDK Studio ([3b231cb](https://github.com/quarklabsai/quarkupy/commit/3b231cbca70dcec2f6c2ba2e403007f25692cb12))
* **client:** add follow_redirects request option ([71b858c](https://github.com/quarklabsai/quarkupy/commit/71b858c1b02a223e69959a469d823fa310583653))


### Chores

* **docs:** remove reference to rye shell ([4b78f0a](https://github.com/quarklabsai/quarkupy/commit/4b78f0a8fb034cce834c8403b1382ccf6bc57363))

## 0.1.0-alpha.3 (2025-05-28)

Full Changelog: [v0.1.0-alpha.2...v0.1.0-alpha.3](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.2...v0.1.0-alpha.3)

### Bug Fixes

* **docs/api:** remove references to nonexistent types ([52601ec](https://github.com/quarklabsai/quarkupy/commit/52601ec2704a3f0794ae3db45a4f56898a929ce4))


### Chores

* **docs:** grammar improvements ([873f20f](https://github.com/quarklabsai/quarkupy/commit/873f20ffeebd635de765ff3e0149485344c23bc9))
* **internal:** codegen related update ([c631505](https://github.com/quarklabsai/quarkupy/commit/c631505aa4fa0fa4f66bd1de502245c748e2c63a))

## 0.1.0-alpha.2 (2025-05-19)

Full Changelog: [v0.1.0-alpha.1...v0.1.0-alpha.2](https://github.com/quarklabsai/quarkupy/compare/v0.1.0-alpha.1...v0.1.0-alpha.2)

### Features

* **api:** update via SDK Studio ([8cb2c16](https://github.com/quarklabsai/quarkupy/commit/8cb2c167245d302e31db694121dbb877b59d26ab))


### Chores

* update SDK settings ([c701cfa](https://github.com/quarklabsai/quarkupy/commit/c701cfa3a75d4c5dd70be579bcb96b683fed1dd0))

## 0.1.0-alpha.1 (2025-05-18)

Full Changelog: [v0.0.1-alpha.1...v0.1.0-alpha.1](https://github.com/quarklabsai/quarkupy/compare/v0.0.1-alpha.1...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([d529592](https://github.com/quarklabsai/quarkupy/commit/d5295926809aff8159cc6478b1c358daaf11be91))
* **api:** update via SDK Studio ([49f0a79](https://github.com/quarklabsai/quarkupy/commit/49f0a79a0cd1b5082c8c32d4407ae86e37445730))

## 0.0.1-alpha.1 (2025-05-17)

Full Changelog: [v0.0.1-alpha.0...v0.0.1-alpha.1](https://github.com/ProjectBifrost/quarkupy/compare/v0.0.1-alpha.0...v0.0.1-alpha.1)

### Chores

* update SDK settings ([d3b18bc](https://github.com/ProjectBifrost/quarkupy/commit/d3b18bc83bd5af999ce0447c348675262ffb23c9))
* update SDK settings ([b1c5dc7](https://github.com/ProjectBifrost/quarkupy/commit/b1c5dc7e10b6902b2fef0c2f56cd9c08c46249b5))
